#!/usr/bin/env python3
# Standard modules
import logging
from argparse import ArgumentParser
from sys import __stdin__
from os import environ, getuid

# Pip modules
from textual.logging import TextualHandler

# Custom modules
from .ddrescue_tui_noninteractive import run_noninteractive
from .ddrescue_tui_app import TUIddrescue


def run_tui():
    """Entry point"""
    p = ArgumentParser(description="TUI for ddrescue, visualizes the progress using the mapfile")
    p.set_defaults(action="")
    p.set_defaults(sudo=False)
    p.add_argument("-i", "--interval", metavar="I", type=int, default=32,
                   help="Initial reload interval (default=32s)")
    sp = p.add_subparsers()
    mp = sp.add_parser("open", help="open mapfile")
    mp.set_defaults(action="open")
    mp.add_argument("mapfile", help="mapfile to read from", type=str)
    mp.add_argument("-n", "--noninteractive", action="store_true", help="Run simple non-interactive mode")
    dp = sp.add_parser("run", help="run ddrescue on startup (sudo required)")
    dp.set_defaults(action="run")
    dp.add_argument("input", metavar="INPUT", help="input file or device", type=str)
    dp.add_argument("output", metavar="OUTPUT", help="output file or folder", type=str)
    dp.add_argument("-o", "--output_name", metavar="OUT", nargs="?", help="output filename", type=str)
    dp.add_argument("-a", "--arguments", metavar="ARGS", help="Custom arguments", type=str)
    args = p.parse_args()
    environ["PYTHONIOENCODING"] = "utf-8"

    if not (args.action == "open" and args.noninteractive) and __stdin__.isatty():
        # Use Textual dev logging
        logging.basicConfig(level="NOTSET", handlers=[TextualHandler()])
        if getuid() == 0:
            args.sudo = True
        elif args.action == "run":
            exit("Subcommand run requires sudo privileges")
        TUIddrescue(args).run()
    else:
        if args.action == "open":
            try:
                run_noninteractive(args)
            except KeyboardInterrupt:
                exit()
        exit("Only subcommand open can be called from a non-interactive terminal")


if __name__ == "__main__":
    run_tui()
