# Standard modules
from time import sleep
from pathlib import Path
from argparse import Namespace

# pip modules
from rich_pixels import Pixels
from rich.console import Console

# Custom modules
from .ddrescue_tui_parser import parse_mapfile
from .ddrescue_tui_plotter import heatmap_image
from .ddrescue_tui_helper import LEGEND


def run_noninteractive(args: Namespace) -> None:
    """Run the application in case the calling terminal is not interactive"""
    c = Console(force_terminal=True, force_interactive=False)
    c.clear()

    # Parse mapfile
    data_arr, data_general = parse_mapfile(Path(args.mapfile), c.width, 10)

    # Mapfile invalid or inexistant
    if data_arr is None:
        exit("Mapfile invalid/inexistant")

    # Create and display plot
    image = heatmap_image(data_arr, c.width, 10)

    c.print(Pixels.from_segments(Pixels._segments_from_image(image, (c.width, 10))))
    c.print(LEGEND)
    c.print(f"{data_general.get('version')} | Reload interval: {args.interval}s | {data_general.get('action') or 'Running...'}")
    c.print("-" * c.width)
    sleep(args.interval)
    run_noninteractive(args)
