from matplotlib import pyplot
from numpy.core import multiarray
from matplotlib.colors import ListedColormap
from PIL import Image

# distinct heatmap colors
COLORS = [
    (0.8, 0.8, 0.8, 1.0),   # 0, grey, non-tried
    (0.0, 1.0, 0.0, 1.0),   # 1, green, rescued
    (1.0, 1.0, 0.0, 1.0),   # 2, yellow, non-trimmed
    (0.0, 0.0, 1.0, 1.0),   # 3, blue, non-scraped
    (1.0, 0.0, 0.0, 1.0),   # 4, red, bad-sectors
    (0.0, 0.0, 0.0, 1.0),   # 5, black, current-sector
    (0.0, 0.0, 0.0, 0.0)    # 6, no black, placeholder
]


def heatmap_image(data: multiarray, x=120, y=30):
    # figsize is inch, x/y are characters; so resizing is necessary anyway
    fig, ax = pyplot.subplots(figsize=(int(x/10), int(y/10)))
    # No axes/border
    ax.axis('off')
    # Heatmap
    pyplot.imshow(data, aspect='auto', origin='upper', cmap=ListedColormap(COLORS), vmin=-0.5, vmax=6.5)
    # No ticks
    pyplot.xticks([])
    pyplot.yticks([])
    pyplot.tick_params(left=False, bottom=False)
    # No padding around plot
    fig.tight_layout(pad=0)
    # Transparent background
    fig.set_facecolor((1, 1, 1, 0))
    # Draw so the plot is in memory
    fig.canvas.draw()

    # Convert memory to PIL image (see https://stackoverflow.com/questions/74150693/matplotlib-convert-canvas-to-rgba)
    img = Image.frombytes(
        'RGBA',
        fig.canvas.get_width_height(),
        bytes(fig.canvas.get_renderer().buffer_rgba())
    )

    # Close so the memory does not fill up
    pyplot.close()
    return img
